@@ -202,7 +202,7 @@ class SpiderMeta(type):
 
 class Spider(metaclass=SpiderMeta):
 
-    urls = [f'https://www.baidu.com']
+    urls = ['https://www.baidu.com']
 
     def __init__(self, opt):
         ''' opt params:
@@ -330,16 +330,16 @@ class Spider(metaclass=SpiderMeta):
                 await self.process(msg)
                 await self.broker.ack()
             except CancelledError:
-                return self.logger.error(f'Cancelled consumer')
+                return self.logger.error('Cancelled consumer')
             except Exception as e:
                 self.logger.exception(e)
                 self.broker.ack()
 
     async def shutdown(self, sig):
-        self.logger.warning('caught {0}'.format(sig.name))
+        self.logger.warning(f'caught signal {sig.name}')
         await self.broker.finish()
         tasks = list(filter(lambda task: task is not asyncio.tasks.Task.current_task(), asyncio.Task.all_tasks()))
-        self.logger.info(f'finished awaiting cancelled tasks: {len(tasks)}')
+        self.logger.info(f'cancell tasks: {len(tasks)}')
         list(map(lambda task: task.cancel(), tasks))
         self.loop.stop()
 
