@@ -28,6 +28,7 @@ from .http_utils import Response
 from .ip_region import Ip2Region
 from .log_utils import Logger
 from .log_utils import WatchedFileHandler
+from .processor import Processor
 from .rabbitmq import AioPika
 from .rabbitmq import Pika
 from .utils import AioQueue
@@ -66,5 +67,5 @@ __all__ = [
     'Config', 'Logger', 'WatchedFileHandler',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient',
     'Mysql', 'AioMysql', 'Pika', 'AioPika',
-    'Request', 'Response', 'Chrome', 'Crypt'
+    'Request', 'Response', 'Chrome', 'Crypt', 'Processor'
 ]
