@@ -9,36 +9,26 @@ import argparse
 import json
 import logging
 import re
+import yaml
 from configparser import ConfigParser
 
-import yaml
 
 from .utils import Dict
 
 
 class Config(Dict):
 
-    def __init__(self, config=None, guess=True, flag=True):
-        if flag and config is None:
+    def __init__(self, config=None, guess=True, parse=True):
+        if config is not None:
+            self._load_cfg(config)
+
+        if parse:
             parser = argparse.ArgumentParser()
             parser.add_argument('--config', type=str, default=None)
             args, _ = parser.parse_known_args()
-            config = args.config
+            if args.config:
+                self._load_cfg(args.config)
 
-        if config is not None:
-            if isinstance(config, dict):
-                self.update(config)
-            elif config.endswith('.ini'):
-                self.update(self._load_ini(config))
-            elif config.endswith('.json'):
-                self.update(json.load(open(config)))
-            elif config.endswith('.yaml') or config.endswith('.yml'):
-                self.update(yaml.load(open(config)))
-            else:
-                raise TypeError(f'{config} must be ini, json or yaml')
-
-        if flag:
-            parser = argparse.ArgumentParser()
             for key, value in self.items():
                 self._add_args(parser, key, value)
 
@@ -52,6 +42,28 @@ class Config(Dict):
             for key, value in args.__dict__.items():
                 self._update(self, key, value)
 
+    def _load_ini(self, config):
+        conf = ConfigParser()
+        conf.read(config)
+        opt = {}
+        for section in conf.sections():
+            opt[section] = {}
+            for key, value in conf.items(section):
+                opt[section][key] = self._convert(value)
+        return opt
+
+    def _load_cfg(self, config):
+        if isinstance(config, dict):
+            self.update(Dict(config))
+        elif config.endswith('.ini'):
+            self.update(Dict(self._load_ini(config)))
+        elif config.endswith('.json'):
+            self.update(Dict(json.load(open(config))))
+        elif config.endswith('.yaml') or config.endswith('.yml'):
+            self.update(Dict(yaml.load(open(config))))
+        else:
+            raise TypeError(f'{config} must be dict, ini, json or yaml')
+
     def _convert(self, value):
         if re.match(r'^-?[\d]+$', value):
             return int(value)
@@ -62,16 +74,6 @@ class Config(Dict):
         else:
             return value
 
-    def _load_ini(self, config):
-        conf = ConfigParser()
-        conf.read(config)
-        opt = Dict()
-        for section in conf.sections():
-            opt[section] = Dict()
-            for key, value in conf.items(section):
-                opt[section][key] = self._convert(value)
-        return opt
-
     def _update(self, opt, key, value):
         if key.find('.') >= 0:
             arr = key.split('.', 1)
