@@ -58,12 +58,12 @@ class MongoClient(pymongo.MongoClient):
 
     def __init__(self, **kwargs):
         env = 'MONGO_LOC' if kwargs.pop('loc', False) and os.environ.get('MONGO_LOC') else 'MONGO_URI'
-        if any([key in kwargs for key in ['host', 'port', 'user', 'pwd']]):
+        if any([key in kwargs for key in ['host', 'port', 'user', 'password']]):
             host = kwargs.pop('host', 'localhost')
             port = kwargs.pop('port', 27017)
             user = kwargs.pop('user', None)
-            pwd = kwargs.pop('pwd', None)
-            uri = f"mongodb://{quote_plus(user)}:{quote_plus(pwd)}@{host}:{port}" if user and pwd else f"mongodb://{host}:{port}"
+            password = kwargs.pop('password', None)
+            uri = f"mongodb://{quote_plus(user)}:{quote_plus(password)}@{host}:{port}" if user and password else f"mongodb://{host}:{port}"
         elif kwargs.get('uri'):
             uri = kwargs.pop('uri')
         elif os.environ.get(env):
@@ -72,8 +72,8 @@ class MongoClient(pymongo.MongoClient):
             host = os.environ.get('MONGO_HOST', 'localhost')
             port = os.environ.get('MONGO_PORT', 27017)
             user = os.environ.get('MONGO_USER', None)
-            pwd = os.environ.get('MONGO_PWD', None)
-            uri = f"mongodb://{quote_plus(user)}:{quote_plus(pwd)}@{host}:{port}" if user and pwd else f"mongodb://{host}:{port}"
+            password = os.environ.get('MONGO_PWD', None)
+            uri = f"mongodb://{quote_plus(user)}:{quote_plus(password)}@{host}:{port}" if user and password else f"mongodb://{host}:{port}"
 
         if 'uri' in kwargs:
             kwargs.pop('uri')
@@ -271,7 +271,7 @@ class AioRedis(aredis.StrictRedis):
 
 class Mysql:
 
-    def __init__(self, host, port=3306, user=None, password='', db=None,
+    def __init__(self, host='localhost', port=3306, user=None, password='', db=None,
                  time_zone='+08:00', max_idle_time=7 * 3600, charset='utf8',
                  sql_mode='TRADITIONAL', autocommit=True, **kwargs):
         init_command = f'SET time_zone = "{time_zone}"'
